"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.RulesTable = void 0;
var RulesTable = {
  isAlphanumeric: function isAlphanumeric(value) {
    return undefined === value || '' === value || /^[A-Za-z0-9]+$/.test(String(value).toLowerCase());
  },
  isEmail: function isEmail(value) {
    return undefined === value || '' === value || /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/.test(String(value).toLowerCase());
  },
  isLengthValid: function isLengthValid(value, props) {
    return undefined === value || '' === value || (undefined === props.minLength || value.length >= props.minLength) && (undefined === props.maxLength || value.length <= props.maxLength);
  },
  isNumber: function isNumber(value) {
    return !Number.isNaN(Number(value));
  },
  isRegexValid: function isRegexValid(value, props) {
    return undefined === value || '' === value || props.regex.test(String(value));
  },
  isRequired: function isRequired(value) {
    return undefined !== value && value.length !== 0 && value !== false;
  },
  isValueValid: function isValueValid(value, props) {
    return undefined === value || '' === value || (undefined === props.min || value >= props.min) && (undefined === props.max || value <= props.max);
  }
};
exports.RulesTable = RulesTable;